Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Ground Station.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

Actions, resources, and condition keys for AWS Ground Station - AWS Identity and Access Management

# Actions, resources, and condition keys for AWS Ground Station

Tip

This page is moving to a new location on November 16, 2020. Please update your bookmark to use the new page at https://docs.aws.amazon.com/service-authorization/latest/reference/list_awsgroundstation.html .

AWS Ground Station (service prefix: `groundstation` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions defined by AWS Ground Station
- Resource types defined by AWS Ground Station
- Condition keys for AWS Ground Station

## Actions defined by AWS Ground Station

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
CancelContact | Grants permission to cancel a contact | Write | Contact* |  |
CreateConfig | Grants permission to create a configuration | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataflowEndpointGroup | Grants permission to create a data flow endpoint group | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
CreateMissionProfile | Grants permission to create a mission profile | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
DeleteConfig | Grants permission to delete a config | Write | Config* |  |
DeleteDataflowEndpointGroup | Grants permission to delete a data flow endpoint group | Write | DataflowEndpointGroup* |  |
DeleteMissionProfile | Grants permission to delete a mission profile | Write | MissionProfile* |  |
DescribeContact | Grants permission to describe a contact | Read | Contact* |  |
GetConfig | Grants permission to return a configuration | Read | Config* |  |
GetDataflowEndpointGroup | Grants permission to return a data flow endpoint group | Read | DataflowEndpointGroup* |  |
GetMinuteUsage | Grants permission to return minutes usage | Read |  |  |
GetMissionProfile | Grants permission to retrieve a mission profile | Read | MissionProfile* |  |
GetSatellite | Grants permission to return information about a satellite | Read | Satellite* |  |
ListConfigs | Grants permisson to return a list of past configurations | List |  |  |
ListContacts | Grants permission to return a list of contacts | List |  |  |
ListDataflowEndpointGroups | Grants permission to list data flow endpoint groups | List |  |  |
ListGroundStations | Grants permission to list ground stations | List |  |  |
ListMissionProfiles | Grants permission to return a list of mission profiles | List |  |  |
ListSatellites | Grants permission to list satellites | List |  |  |
ListTagsForResource | Grants permission to list tags for a resource | Read | Config |  |
Contact |  |
DataflowEndpointGroup |  |
MissionProfile |  |
ReserveContact | Grants permission to reserve a contact | Write |  | aws:RequestTag/${TagKey} aws:TagKeys |
TagResource | Grants permission to assign a resource tag | Tagging | Config |  |
Contact |  |
DataflowEndpointGroup |  |
MissionProfile |  |
| aws:TagKeys aws:RequestTag/${TagKey} |
UntagResource | Grants permission to deassign a resource tag | Tagging | Config |  |
Contact |  |
DataflowEndpointGroup |  |
MissionProfile |  |
| aws:TagKeys |
UpdateConfig | Grants permission to update a configuration | Write | Config* |  |
UpdateMissionProfile | Grants permission to update a mission profile | Write | MissionProfile* |  |

## Resource types defined by AWS Ground Station

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
Config | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:config/$ { configType}/$ { configId}` | aws:ResourceTag/${TagKey} groundstation:configId groundstation:configType
Contact | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:contact/$ { contactId}` | aws:ResourceTag/${TagKey} groundstation:contactId
DataflowEndpointGroup | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:dataflow-endpoint-group/$ { dataflowEndpointGroupId}` | aws:ResourceTag/${TagKey} groundstation:dataflowEndpointGroupId
GroundStationResource | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:groundstation:$ { groundStationId}` | groundstation:groundStationId
MissionProfile | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:mission-profile/$ { missionProfileId}` | aws:ResourceTag/${TagKey} groundstation:missionProfileId
Satellite | `arn:$ { Partition}:groundstation:$ { Region}:$ { Account}:satellite/$ { satelliteId}` | groundstation:satelliteId

## Condition keys for AWS Ground Station

AWS Ground Station defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by a key that is present in the request the user makes to the Ground Station service. | String
aws:ResourceTag/${TagKey} | Filters access by a tag key and value pair. | String
aws:TagKeys | Filters access by the list of all the tag key names present in the request the user makes to the Ground Station service. | String
groundstation:configId | Filters access by the ID of a config | String
groundstation:configType | Filters access by the type of a config | String
groundstation:contactId | Filters access by the ID of a contact | String
groundstation:dataflowEndpointGroupId | Filters access by the ID of a dataflow endpoint group | String
groundstation:groundStationId | Filters access by the ID of a ground station | String
groundstation:missionProfileId | Filters access by the ID of a mission profile | String
groundstation:satelliteId | Filters access by the ID of a satellite | String

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.